==> paraview-v5.5.0.zip: paraview-v5.5.0/Qt/Components/pqCatalystExportStateWizard.h <==
/*=========================================================================

   Program: ParaView
   Module:    pqCatalystExportStateWizard.h

   Copyright (c) 2005,2006 Sandia Corporation, Kitware Inc.
   All rights reserved.

   ParaView is a free software; you can redistribute it and/or modify it
   under the terms of the ParaView license version 1.2.

   See License_v1.2.txt for the full ParaView license.
   A copy of this license can be obtained by contacting
   Kitware Inc.
   28 Corporate Drive
   Clifton Park, NY 12065
   USA

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

========================================================================*/
#ifndef pqCatalystExportStateWizard_h
#define pqCatalystExportStateWizard_h

#include "pqComponentsModule.h"
#include "pqSGExportStateWizard.h"

class PQCOMPONENTS_EXPORT pqCatalystExportStateWizard : public pqSGExportStateWizard
{
  Q_OBJECT
  typedef pqSGExportStateWizard Superclass;

public:
  pqCatalystExportStateWizard(QWidget* parentObject = 0, Qt::WindowFlags parentFlags = 0);
  virtual ~pqCatalystExportStateWizard();

  virtual void customize();

protected:
  virtual bool getCommandString(QString& command);

private:
  Q_DISABLE_COPY(pqCatalystExportStateWizard)
};

#endif

==> paraview-v5.6.2.zip: paraview-v5.6.2/Qt/Components/pqCatalystExportStateWizard.h <==
/*=========================================================================

   Program: ParaView
   Module:    pqCatalystExportStateWizard.h

   Copyright (c) 2005,2006 Sandia Corporation, Kitware Inc.
   All rights reserved.

   ParaView is a free software; you can redistribute it and/or modify it
   under the terms of the ParaView license version 1.2.

   See License_v1.2.txt for the full ParaView license.
   A copy of this license can be obtained by contacting
   Kitware Inc.
   28 Corporate Drive
   Clifton Park, NY 12065
   USA

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

========================================================================*/
#ifndef pqCatalystExportStateWizard_h
#define pqCatalystExportStateWizard_h

#include "pqComponentsModule.h"
#include "pqSGExportStateWizard.h"

/**
 * @class pqCatalystExportStateWizard
 * @deprecated ParaView 5.6
 *
 * pqCatalystExportStateWizard has been deprecated in ParaView 5.6 and has
 * been replaced by pqCatalystExportInspector
*/
class PQCOMPONENTS_EXPORT pqCatalystExportStateWizard : public pqSGExportStateWizard
{
  Q_OBJECT
  typedef pqSGExportStateWizard Superclass;

public:
  pqCatalystExportStateWizard(QWidget* parentObject = 0, Qt::WindowFlags parentFlags = 0);
  virtual ~pqCatalystExportStateWizard();

  virtual void customize();

protected:
  virtual bool getCommandString(QString& command);

private:
  Q_DISABLE_COPY(pqCatalystExportStateWizard)
};

#endif
